#########################################################################
#                                                                       #
#                     Makefile for Base Calculator                      #
#                   Copyright (C) 1997, John Zaitseff                   #
#                                                                       #
#########################################################################

# Author:    John Zaitseff <J.Zaitseff@unsw.edu.au>
# Date:      20th December, 1997.
# Version:   1.4

# This file compiles the Base Calculator program and associated help file.
# This program, including this file, is under the terms of the GNU General
# Public License.

# Syntax:
#     MAKE [all | program | debug | nodebug | help | clean]
#
# make all       - make all targets that are not up-to-date
# make program   - make sure the program BASECALC.EXE is up-to-date
# make debug     - force recompilation of the program with debugging code
# make nodebug   - force recompilation of the program without debugging code
# make help      - make sure the help file BASECALC.HLP is up-to-date
# make clean     - remove all unnecessary files

# Some parts of this file may need to be customised for your specific set-up.


#########################################################################
# Define the following macros to point to the location of the Delphi v2
# compiler and help workshop, then comment out the !error line:

!error Makefile has not been modified to set the path of the Delphi compiler.
DELPHI       = C:\Apps\Delphi\Bin
DELHLP       = C:\Apps\Delphi\Help\Tools

# Uncomment the next line for Windows NT 3.51 or earlier:
#WINNT35      = 1

#########################################################################
# Additional macros:

EXOPT        = -m -DOPTDEBUG
EXOPTDEBUG   = -b -DOPTDEBUG -DDEBUG -V
EXOPTNODEBUG = -b -DOPTDEBUG

!if $d(WINNT35)
STARTCMD =
!else
STARTCMD = start /w
!endif

#########################################################################
# Targets:

all:     program help
program: basecalc.exe
help:    basecalc.hlp

#########################################################################
# Compile main program and associated units:

SOURCES     = BaseCalc.dpr BaseCalc.res About.pas About.dfm BCalcWin.pas \
              BCalcWin.dfm Calc.pas Value.pas Value.dfm VerRes.pas

basecalc.exe: $(SOURCES)
         $(DELPHI)\dcc32 $(EXOPT) BaseCalc.dpr
         ren BaseCalc.exe BASECALC.EXE

BaseCalc.res: BaseCalc.rc BaseCalc.ico winverRC.h
         $(DELPHI)\brcc32 -w32 -fo$@ BaseCalc.rc

#########################################################################
# Debugging and no-debugging targets.  These force recompilation.

debug:   $(SOURCES)
         $(DELPHI)\dcc32 $(EXOPTDEBUG) BaseCalc.dpr
         ren BaseCalc.exe BASECALC.EXE

nodebug: $(SOURCES)
         $(DELPHI)\dcc32 $(EXOPTNODEBUG) BaseCalc.dpr
         ren BaseCalc.exe BASECALC.EXE

#########################################################################
# Compile help file:

basecalc.hlp: BaseCalc.cnt Help\BaseCalc.rtf Help\BaseCalc.hpj
         cd Help
         $(STARTCMD) $(DELHLP)\hcrtf /x BaseCalc.hpj
         cd ..
         ren BaseCalc.cnt BASECALC.CNT
         ren BaseCalc.hlp BASECALC.HLP
         winhlp32 -G BASECALC.HLP
         attrib -h BaseCalc.gid
         ren BaseCalc.gid BASECALC.GID
         attrib +h BASECALC.GID

#########################################################################
# Clean unnecessary files:

clean:
         -del *.bak
         -del *.~*
         -del *.dcu
         -del *.res
